<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Session;
use App\Helpers\EncryptDecrypt;
use App\Traits\ConsumeExternalService;
use App\Helpers\s3upload;


class EventController extends Controller
{
    use ConsumeExternalService;



    public function event()
    {
         
        $loginUserData = Session::get('login_user_data');
        $user_id = $loginUserData->user_id;
        $userToken = Session::get('user_token');
        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];


        $post_data = array(
            'latitude'=>"22.9778146",
            'longitude'=>"72.4979419",
        );

        $requestUri = "/v1/common/nearby_events";
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", $requestUri, $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        $event = $response_decoded;

        $events = $response_decoded->data;
        $eventCount = count($events);

        // dd($event);
       

        
        return view('user.event.event',compact('event','eventCount'));
       
    }



    public function create_event()
    {
         
        $loginUserData = Session::get('login_user_data');
        $user_id = $loginUserData->user_id;
        $userToken = Session::get('user_token');
        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];



        $requestUri = "/v1/common/flag_list";
        $data_response = $this->performRequest("POST", $requestUri,null, $formParams);
        $data_response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($data_response));
        $flatData = $data_response_decoded;

        // dd($flatData);
       
        
        return view('user.event.create_event',compact('flatData'));
       
    }



    public function create_event_post(Request $request)
    {

        $loginUserData = Session::get('login_user_data');
        $user_id = $loginUserData->user_id;
        $userToken = Session::get('user_token');
        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];

        $post_data = array(
            'name'=>$request->name,
            'flag_id'=>$request->flag_id,
            'location'=>$request->location,
            'latitude'=>$request->latitude,
            'longitude'=>$request->longitude,
            'description'=>$request->description,
            'start_date'=>$request->start_date,
            'end_date'=>$request->end_date,
        );


        if ($request->has('logo')) {
            $file = $request->file('logo');
            $imageName = $file->getClientOriginalName();
            $tmpFile = $file->getRealPath();
            $path = env('AWS_BUCKET_FOLDER') . env('EVENT_LOGO_IMAGES');
            $contents = s3upload::uploadImage($imageName, $tmpFile, $path);
            $post_data['logo'] = $contents;
        }

        // dd($post_data);

        $requestUri = "/v1/common/add_event";
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", $requestUri, $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        $event = $response_decoded;

        // dd($event); 
       
        
        if ($response_decoded->code == 1) {  
            return redirect()->route('event');
        }else{
            return redirect()->back()->with('error', $response_decoded->message);

        }
       
    }



    public function event_list()
    {
         
        $loginUserData = Session::get('login_user_data');
        $user_id = $loginUserData->user_id;
        $userToken = Session::get('user_token');
        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];

        $post_data = array(
            'page'=>"1",

        );

        $requestUri = "/v1/common/event_list";
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", $requestUri, $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        $event = $response_decoded;

        // dd($event);
        
        return view('user.event.event_list',compact('event'));
       
    }


    public function event_detail(Request $request)
    {
         
        $loginUserData = Session::get('login_user_data');
        $user_id = $loginUserData->user_id;
        $userToken = Session::get('user_token');
        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];

        Session::put('event_id', $request->event_id);

        $post_data = array(
            'event_id'=>$request->event_id,
        );

        $requestUri = "/v1/common/event_details";
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", $requestUri, $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        $event = $response_decoded;


        $output['url'] =route('event_info');

        return response()->json($output);
          
    }

    public function event_info(Request $request)
    {
         
        $loginUserData = Session::get('login_user_data');
        $user_id = $loginUserData->user_id;
        $userToken = Session::get('user_token');
        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];

        $eventID = Session::get('event_id');

        // dd($eventID);


        $post_data = array(
            'event_id'=>$eventID,
        );

        // dd($post_data);

        $requestUri = "/v1/common/event_details";
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", $requestUri, $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        $event = $response_decoded;

        // dd($event);

        return view('user.event.event_info',compact('event'));
          
    }
}
